==> CommonEnvironment-1.0.1.tar.gz: CommonEnvironment-1.0.1/CommonEnvironment/Shell/UnitTests/WindowsShell_UnitTest.py <==
# ----------------------------------------------------------------------
# |  
# |  WindowsShell_UnitTest.py
# |  
# |  David Brownell <db@DavidBrownell.com>
# |      2018-08-21 07:38:01
# |  
# ----------------------------------------------------------------------
# |  
# |  Copyright David Brownell 2018.
# |  Distributed under the Boost Software License, Version 1.0.
# |  (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
# |  
# ----------------------------------------------------------------------
"""Unit test for WindowsShell.py"""

import os
import sys
import unittest

from CommonEnvironment.Shell.WindowsShell import *

# ----------------------------------------------------------------------
_script_fullpath = os.path.abspath(__file__) if "python" in sys.executable.lower() else sys.executable
_script_dir, _script_name = os.path.split(_script_fullpath)
# ----------------------------------------------------------------------

# ----------------------------------------------------------------------
class StandardSuite(unittest.TestCase):
    @unittest.skip("Not implemented")
    def test_Placeholder(self):
        self.assertTrue(False)
        
# ----------------------------------------------------------------------
# ----------------------------------------------------------------------
# ----------------------------------------------------------------------
if __name__ == "__main__":
    try: sys.exit(unittest.main(verbosity=2))
    except KeyboardInterrupt: pass

==> CommonEnvironment-1.0.5.tar.gz: CommonEnvironment-1.0.5/CommonEnvironment/Shell/UnitTests/WindowsShell_UnitTest.py <==
# ----------------------------------------------------------------------
# |  
# |  WindowsShell_UnitTest.py
# |  
# |  David Brownell <db@DavidBrownell.com>
# |      2018-08-21 07:38:01
# |  
# ----------------------------------------------------------------------
# |  
# |  Copyright David Brownell 2018-19.
# |  Distributed under the Boost Software License, Version 1.0.
# |  (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
# |  
# ----------------------------------------------------------------------
"""Unit test for WindowsShell.py"""

import os
import sys
import unittest

import CommonEnvironment
from CommonEnvironment.Shell.WindowsShell import *

# ----------------------------------------------------------------------
_script_fullpath = CommonEnvironment.ThisFullpath()
_script_dir, _script_name = os.path.split(_script_fullpath)
# ----------------------------------------------------------------------

# ----------------------------------------------------------------------
class StandardSuite(unittest.TestCase):
    @unittest.skip("Not implemented")
    def test_Placeholder(self):
        self.assertTrue(False)
        
# ----------------------------------------------------------------------
# ----------------------------------------------------------------------
# ----------------------------------------------------------------------
if __name__ == "__main__":
    try: sys.exit(unittest.main(verbosity=2))
    except KeyboardInterrupt: pass
